Module blaxel.core.client.models.logs_response
==============================================

Classes
-------

`LogsResponse(data: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>)`
:   Response for logs
    
    Attributes:
        data (Union[Unset, list[Any]]): Data
    
    Method generated by attrs for class LogsResponse.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `data: blaxel.core.client.types.Unset | list[typing.Any]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :